NaMaster: namaster.h Source File

NaMaster

- Main Page
- Data Structures
- Files

- File List
- Globals

namaster.h
Go to the documentation of this file.
1 #ifndef _NAMASTER_H_
2 #define _NAMASTER_H_
3
4 #ifndef NO_DOXY
5 #include <stdio.h>
6 #include <stdlib.h>
7 #include <stdarg.h>
8 #include <string.h>
9 #include <unistd.h>
10 #include <math.h>
11 #include <time.h>
12 #include <complex.h>
13 #include <gsl/gsl_vector.h>
14 #include <gsl/gsl_matrix.h>
15 #include <gsl/gsl_linalg.h>
16 #include <gsl/gsl_blas.h>
17 #include <gsl/gsl_eigen.h>
18 #include <gsl/gsl_rng.h>
19 #include <gsl/gsl_randist.h>
20 #include <gsl/gsl_spline.h>
21 #include <gsl/gsl_integration.h>
22 #include <fftw3.h>
23 #endif //NO_DOXY
24
25 #define NMT_MAX(a,b) (((a)>(b)) ? (a) : (b)) // maximum
26 #define NMT_MIN(a,b) (((a)<(b)) ? (a) : (b)) // minimum
27
28 #ifdef _SPREC
29 typedef float flouble;
30 typedef float complex fcomplex;
31 #else //_SPREC
32 typedef double flouble;
33 typedef double complex fcomplex;
34 #endif //_SPREC
35
71 typedef struct {
72 int n_bands;
73 flouble *ell_0_list;
74 flouble *ell_f_list;
75 } nmt_binning_scheme_flat;
76
86 nmt_binning_scheme_flat *nmt_bins_flat_constant(int nlb,flouble lmax);
87
96 nmt_binning_scheme_flat *nmt_bins_flat_create(int nell,flouble *l0,flouble *lf);
97
101 void nmt_bins_flat_free(nmt_binning_scheme_flat *bin);
102
115 void nmt_bin_cls_flat(nmt_binning_scheme_flat *bin,int nl,flouble *larr,flouble **cls_in,
116 flouble **cls_out,int ncls);
117
131 void nmt_unbin_cls_flat(nmt_binning_scheme_flat *bin,flouble **cls_in,
132 int nl,flouble *larr,flouble **cls_out,int ncls);
133
142 void nmt_ell_eff_flat(nmt_binning_scheme_flat *bin,flouble *larr);
143
156 int nmt_bins_flat_search_fast(nmt_binning_scheme_flat *bin,flouble l,int il);
157
166 typedef struct {
167 int n_bands;
168 int *nell_list;
169 int **ell_list;
170 flouble **w_list;
171 flouble **f_ell;
172 int ell_max;
173 } nmt_binning_scheme;
174
185 nmt_binning_scheme *nmt_bins_constant(int nlb,int lmax,int is_l2);
186
202 nmt_binning_scheme *nmt_bins_create(int nell,int *bpws,int *ells,flouble *weights,
203 flouble *f_ell,int lmax);
204
216 nmt_binning_scheme *nmt_bins_read(char *fname,int lmax);
217
221 void nmt_bins_free(nmt_binning_scheme *bin);
222
233 void nmt_bin_cls(nmt_binning_scheme *bin,flouble **cls_in,flouble **cls_out,int ncls);
234
246 void nmt_unbin_cls(nmt_binning_scheme *bin,flouble **cls_in,flouble **cls_out,int ncls);
247
256 void nmt_ell_eff(nmt_binning_scheme *bin,flouble *larr);
257
265 typedef struct {
266 int is_const;
267 flouble x0;
268 flouble xf;
269 flouble y0;
270 flouble yf;
271 gsl_spline *spl;
272 } nmt_k_function;
273
286 nmt_k_function *nmt_k_function_alloc(int nk,flouble *karr,flouble *farr,
287 flouble y0,flouble yf,int is_const);
288
292 void nmt_k_function_free(nmt_k_function *f);
293
302 flouble nmt_k_function_eval(nmt_k_function *f,flouble k,gsl_interp_accel *intacc);
303
311 typedef struct {
312 int nx;
313 int ny;
314 long npix;
315 flouble lx;
316 flouble ly;
317 flouble pixsize;
318 int n_ell;
319 flouble dell;
320 flouble i_dell;
321 flouble *ell_min;
322 // int *n_cells;
323 } nmt_flatsky_info;
324
335 nmt_flatsky_info *nmt_flatsky_info_alloc(int nx,int ny,flouble lx,flouble ly);
336
340 void nmt_flatsky_info_free(nmt_flatsky_info *fs);
341
348 typedef struct {
349 nmt_flatsky_info *fs;
350 long npix;
351 int pure_e;
352 int pure_b;
353 flouble *mask;
354 fcomplex **a_mask;
355 int spin;
356 int nmaps;
357 flouble **maps;
358 fcomplex **alms;
359 int ntemp;
360 flouble ***temp;
361 fcomplex ***a_temp;
362 gsl_matrix *matrix_M;
363 nmt_k_function *beam;
364 int lite;
365 int mask_only;
366 } nmt_field_flat;
367
371 void nmt_field_flat_free(nmt_field_flat *fl);
372
408 nmt_field_flat *nmt_field_flat_alloc(int nx,int ny,flouble lx,flouble ly,
409 flouble *mask,int spin,flouble **maps,int ntemp,flouble ***temp,
410 int nl_beam,flouble *l_beam,flouble *beam,
411 int pure_e,int pure_b,double tol_pinv,int masked_input,
412 int is_lite,int mask_only);
438 flouble **nmt_synfast_flat(int nx,int ny,flouble lx,flouble ly,int nfields,int *spin_arr,
439 int nl_beam,flouble *l_beam,flouble **beam_fields,
440 int nl_cell,flouble *l_cell,flouble **cell_fields,
441 int seed);
442
454 void nmt_purify_flat(nmt_field_flat *fl,flouble *mask,fcomplex **walm0,
455 flouble **maps_in,flouble **maps_out,fcomplex **alms);
456
470 typedef struct {
471 int is_healpix;
472 long n_eq;
473 int lmax_sht;
474 int nx_short;
475 int nx;
476 int ny;
477 long npix;
478 flouble Delta_theta;
479 flouble Delta_phi;
480 flouble phi0; // longitude of first pixel
481 flouble theta0; // colatitude of last ring
482 } nmt_curvedsky_info;
483
490 nmt_curvedsky_info *nmt_curvedsky_info_copy(nmt_curvedsky_info *cs_in);
491
510 nmt_curvedsky_info *nmt_curvedsky_info_alloc(int is_healpix,long nside,
511 int lmax_sht,
512 int nx0,int ny0,flouble Dtheta,flouble Dphi,
513 flouble phi0,flouble theta0);
514
515
521 int nmt_diff_curvedsky_info(nmt_curvedsky_info *c1, nmt_curvedsky_info *c2);
522
535 flouble *nmt_extend_CAR_map(nmt_curvedsky_info *cs,flouble *map_in);
536
543 typedef struct {
544 nmt_curvedsky_info *cs;
545 long npix;
546 int lmax;
547 int pure_e;
548 int pure_b;
549 flouble *mask;
550 fcomplex **a_mask;
551 int spin;
552 int nmaps;
553 flouble **maps;
554 fcomplex **alms;
555 int ntemp;
556 flouble ***temp;
557 fcomplex ***a_temp;
558 gsl_matrix *matrix_M;
559 flouble *beam;
560 int lite;
561 int mask_only;
562 } nmt_field;
563
567 void nmt_field_free(nmt_field *fl);
568
605 nmt_field *nmt_field_alloc_sph(nmt_curvedsky_info *cs,flouble *mask,int spin,flouble **maps,
606 int ntemp,flouble ***temp,flouble *beam,
607 int pure_e,int pure_b,int n_iter_mask_purify,double tol_pinv,
608 int niter,int masked_input,int is_lite,int mask_only);
609
641 nmt_field *nmt_field_read(int is_healpix,char *fname_mask,char *fname_maps,char *fname_temp,
642 char *fname_beam,int spin,int pure_e,int pure_b,
643 int n_iter_mask_purify,double tol_pinv,int niter);
644
664 flouble **nmt_synfast_sph(nmt_curvedsky_info *cs,int nfields,int *spin_arr,int lmax,
665 flouble **cells,flouble **beam_fields,int seed);
666
679 void nmt_purify(nmt_field *fl,flouble *mask,fcomplex **walm0,
680 flouble **maps_in,flouble **maps_out,fcomplex **alms,int niter);
681
719 void nmt_apodize_mask(long nside,flouble *mask_in,flouble *mask_out,flouble aposize,char *apotype);
720
721
735 void nmt_apodize_mask_flat(int nx,int ny,flouble lx,flouble ly,
736 flouble *mask_in,flouble *mask_out,flouble aposize,char *apotype);
737
743 typedef struct {
744 int ncls;
745 flouble ellcut_x[2];
746 flouble ellcut_y[2];
747 int pe1;
748 int pe2;
749 int pb1;
750 int pb2;
751 nmt_flatsky_info *fs;
752 int is_teb;
753 int *n_cells;
754 flouble **coupling_matrix_unbinned;
755 flouble **coupling_matrix_binned;
756 nmt_binning_scheme_flat *bin;
757 flouble lmax;
758 gsl_matrix *coupling_matrix_binned_gsl;
759 gsl_permutation *coupling_matrix_perm;
760 } nmt_workspace_flat;
761
765 void nmt_workspace_flat_free(nmt_workspace_flat *w);
766
781 nmt_workspace_flat *nmt_compute_coupling_matrix_flat(nmt_field_flat *fl1,nmt_field_flat *fl2,
782 nmt_binning_scheme_flat *bin,
783 flouble lmn_x,flouble lmx_x,
784 flouble lmn_y,flouble lmx_y,int is_teb);
785
808 void nmt_compute_deprojection_bias_flat(nmt_field_flat *fl1,nmt_field_flat *fl2,
809 nmt_binning_scheme_flat *bin,
810 flouble lmn_x,flouble lmx_x,flouble lmn_y,flouble lmx_y,
811 int nl_prop,flouble *l_prop,flouble **cl_proposal,
812 flouble **cl_bias);
813
832 void nmt_couple_cl_l_flat_fast(nmt_workspace_flat *w,int nl,flouble *larr,flouble **cl_in,
833 flouble **cl_out);
847 void nmt_couple_cl_l_flat_quick(nmt_workspace_flat *w,int nl,flouble *larr,flouble **cl_in,
848 flouble **cl_out);
849
864 void nmt_decouple_cl_l_flat(nmt_workspace_flat *w,flouble **cl_in,flouble **cl_noise_in,
865 flouble **cl_bias,flouble **cl_out);
866
885 void nmt_compute_coupled_cell_flat(nmt_field_flat *fl1,nmt_field_flat *fl2,
886 nmt_binning_scheme_flat *bin,flouble **cl_out,
887 flouble lmn_x,flouble lmx_x,flouble lmn_y,flouble lmx_y);
888
920 nmt_workspace_flat *nmt_compute_power_spectra_flat(nmt_field_flat *fl1,nmt_field_flat *fl2,
921 nmt_binning_scheme_flat *bin,
922 flouble lmn_x,flouble lmx_x,
923 flouble lmn_y,flouble lmx_y,
924 nmt_workspace_flat *w0,flouble **cl_noise,
925 int nl_prop,flouble *l_prop,flouble **cl_prop,
926 flouble **cl_out);
927
933 typedef struct {
934 int lmax;
935 int lmax_fields;
936 int lmax_mask;
937 int is_teb;
938 int ncls;
939 nmt_curvedsky_info *cs;
940 flouble *beam_prod;
941 flouble *pcl_masks;
942 flouble **coupling_matrix_unbinned;
943 nmt_binning_scheme *bin;
944 gsl_matrix *coupling_matrix_binned;
945 gsl_permutation *coupling_matrix_perm;
946 } nmt_workspace;
947
948 typedef struct {
949 int lmax;
950 int lmax_mask;
951 int npcl;
952 int s1;
953 int s2;
954 int has_00;
955 flouble ***xi_00;
956 int has_0s;
957 flouble ****xi_0s;
958 int has_ss;
959 flouble ****xi_pp;
960 flouble ****xi_mm;
961 int pure_e1;
962 int pure_e2;
963 int pure_b1;
964 int pure_b2;
965 int pure_any;
966 int npure_0s;
967 int npure_ss;
968 } nmt_master_calculator;
969
970 nmt_master_calculator *nmt_compute_master_coefficients(int lmax, int lmax_mask,
971 int npcl, flouble **pcl_masks,
972 int s1, int s2,
973 int pure_e1, int pure_b1,
974 int pure_e2, int pure_b2,
975 int do_teb, int l_toeplitz,
976 int l_exact, int dl_band);
977 void nmt_master_calculator_free(nmt_master_calculator *c);
978
991 nmt_workspace *nmt_compute_coupling_matrix(nmt_field *fl1,nmt_field *fl2,nmt_binning_scheme *bin,
992 int is_teb,int niter,int lmax_mask,
993 int l_toeplitz,int l_exact,int dl_band);
994
1007 void nmt_update_coupling_matrix(nmt_workspace *w,int n_rows,double *new_matrix);
1008
1016 void nmt_workspace_update_binning(nmt_workspace *w,
1017 nmt_binning_scheme *bin);
1018
1029 void nmt_workspace_update_beams(nmt_workspace *w,
1030 int nl1,double *b1,
1031 int nl2,double *b2);
1032
1036 void nmt_workspace_free(nmt_workspace *w);
1037
1052 void nmt_compute_deprojection_bias(nmt_field *fl1,nmt_field *fl2,
1053 flouble **cl_proposal,flouble **cl_bias,int niter);
1054
1068 void nmt_compute_uncorr_noise_deprojection_bias(nmt_field *fl1,flouble *map_var,flouble **cl_bias,
1069 int niter);
1070
1085 void nmt_couple_cl_l(nmt_workspace *w,flouble **cl_in,flouble **cl_out);
1086
1101 void nmt_decouple_cl_l(nmt_workspace *w,flouble **cl_in,flouble **cl_noise_in,
1102 flouble **cl_bias,flouble **cl_out);
1103
1113 void nmt_compute_bandpower_windows(nmt_workspace *w,double *bpw_win_out);
1114
1127 void nmt_compute_coupled_cell(nmt_field *fl1,nmt_field *fl2,flouble **cl_out);
1128
1154 nmt_workspace *nmt_compute_power_spectra(nmt_field *fl1,nmt_field *fl2,
1155 nmt_binning_scheme *bin,nmt_workspace *w0,
1156 flouble **cl_noise,flouble **cl_proposal,flouble **cl_out,
1157 int niter,int lmax_mask,int l_toeplitz,
1158 int l_exact,int dl_band);
1159
1167 typedef struct {
1168 nmt_binning_scheme_flat *bin;
1169 flouble **xi00_1122;
1170 flouble **xi00_1221;
1171 flouble **xi02_1122;
1172 flouble **xi02_1221;
1173 flouble **xi22p_1122;
1174 flouble **xi22p_1221;
1175 flouble **xi22m_1122;
1176 flouble **xi22m_1221;
1177 } nmt_covar_workspace_flat;
1178
1182 void nmt_covar_workspace_flat_free(nmt_covar_workspace_flat *cw);
1183
1196 nmt_covar_workspace_flat *nmt_covar_workspace_flat_init(nmt_field_flat *fla1,nmt_field_flat *fla2,
1197 nmt_binning_scheme_flat *ba,
1198 nmt_field_flat *flb1,nmt_field_flat *flb2,
1199 nmt_binning_scheme_flat *bb);
1200
1223 void nmt_compute_gaussian_covariance_flat(nmt_covar_workspace_flat *cw,
1224 int spin_a,int spin_b,int spin_c,int spin_d,
1225 nmt_workspace_flat *wa,nmt_workspace_flat *wb,
1226 int nl,flouble *larr,
1227 flouble **clac,flouble **clad,
1228 flouble **clbc,flouble **clbd,flouble *covar_out);
1229
1236 typedef struct {
1237 int lmax;
1238 flouble **xi00_1122;
1239 flouble **xi00_1221;
1240 flouble **xi02_1122;
1241 flouble **xi02_1221;
1242 flouble **xi22p_1122;
1243 flouble **xi22p_1221;
1244 flouble **xi22m_1122;
1245 flouble **xi22m_1221;
1246 } nmt_covar_workspace;
1247
1251 void nmt_covar_workspace_free(nmt_covar_workspace *cw);
1252
1265 nmt_covar_workspace *nmt_covar_workspace_init(nmt_field *fla1,nmt_field *fla2,
1266 nmt_field *flb1,nmt_field *flb2,
1267 int lmax,int niter,
1268 int l_toeplitz,int l_exact,int dl_band);
1269
1291 void nmt_compute_gaussian_covariance(nmt_covar_workspace *cw,
1292 int spin_a,int spin_b,int spin_c,int spin_d,
1293 nmt_workspace *wa,nmt_workspace *wb,
1294 flouble **clac,flouble **clad,
1295 flouble **clbc,flouble **clbd,
1296 flouble *covar_out);
1297
1319 void nmt_compute_gaussian_covariance_coupled(nmt_covar_workspace *cw,
1320 int spin_a,int spin_b,int spin_c,int spin_d,
1321 nmt_workspace *wa,nmt_workspace *wb,
1322 flouble **clac,flouble **clad,
1323 flouble **clbc,flouble **clbd,
1324 flouble *covar_out);
1325
1336 void nmt_workspace_write_fits(nmt_workspace *w,char *fname);
1337
1347 nmt_workspace *nmt_workspace_read_fits(char *fname);
1348
1358 nmt_workspace_flat *nmt_workspace_flat_read_fits(char *fname);
1359
1370 void nmt_workspace_flat_write_fits(nmt_workspace_flat *w,char *fname);
1371
1382 void nmt_covar_workspace_write_fits(nmt_covar_workspace *cw,char *fname);
1383
1393 nmt_covar_workspace *nmt_covar_workspace_read_fits(char *fname);
1394
1405 void nmt_covar_workspace_flat_write_fits(nmt_covar_workspace_flat *cw,char *fname);
1406
1416 nmt_covar_workspace_flat *nmt_covar_workspace_flat_read_fits(char *fname);
1417
1418 #endif //_NAMASTER_H_
nmt_master_calculator::pure_b2
int pure_b2
Definition: namaster.h:964
nmt_field::pure_e
int pure_e
>0 if E-modes have been purified
Definition: namaster.h:547
nmt_field::a_temp
fcomplex *** a_temp
Spherical harmonic transfomrs of template maps (mask-multiplied AND purified if requested).
Definition: namaster.h:557
nmt_covar_workspace_read_fits
nmt_covar_workspace * nmt_covar_workspace_read_fits(char *fname)
Builds nmt_covar_workspace structure from file.
nmt_purify
void nmt_purify(nmt_field *fl, flouble *mask, fcomplex **walm0, flouble **maps_in, flouble **maps_out, fcomplex **alms, int niter)
E- or B-mode purifies a given pair of full-sky (Q,U) maps.
nmt_master_calculator
Definition: namaster.h:948
nmt_workspace_update_binning
void nmt_workspace_update_binning(nmt_workspace *w, nmt_binning_scheme *bin)
Updates the binning scheme associated to this workspace.
nmt_workspace_flat::pe2
int pe2
Is the E-mode component of the second field purified?
Definition: namaster.h:748
nmt_bins_flat_constant
nmt_binning_scheme_flat * nmt_bins_flat_constant(int nlb, flouble lmax)
nmt_binning_scheme_flat constructor for constant bandpowers
nmt_bins_flat_create
nmt_binning_scheme_flat * nmt_bins_flat_create(int nell, flouble *l0, flouble *lf)
nmt_binning_scheme_flat generic constructor.
nmt_workspace_flat_read_fits
nmt_workspace_flat * nmt_workspace_flat_read_fits(char *fname)
Builds nmt_workspace_flat structure from file.
nmt_k_function
Flat-sky Fourier-space function.
Definition: namaster.h:265
nmt_field_free
void nmt_field_free(nmt_field *fl)
nmt_field destructor.
nmt_master_calculator::lmax_mask
int lmax_mask
Definition: namaster.h:950
nmt_workspace_flat_free
void nmt_workspace_flat_free(nmt_workspace_flat *w)
nmt_workspace_flat destructor
nmt_field_flat::a_temp
fcomplex *** a_temp
Fourier-transfomrs of template maps (mask-multiplied AND purified if requested).
Definition: namaster.h:361
nmt_curvedsky_info::ny
int ny
Number of grid points in the theta dimension.
Definition: namaster.h:476
nmt_couple_cl_l_flat_quick
void nmt_couple_cl_l_flat_quick(nmt_workspace_flat *w, int nl, flouble *larr, flouble **cl_in, flouble **cl_out)
Mode-couples an input power spectrum.
nmt_compute_gaussian_covariance_flat
void nmt_compute_gaussian_covariance_flat(nmt_covar_workspace_flat *cw, int spin_a, int spin_b, int spin_c, int spin_d, nmt_workspace_flat *wa, nmt_workspace_flat *wb, int nl, flouble *larr, flouble **clac, flouble **clad, flouble **clbc, flouble **clbd, flouble *covar_out)
Compute flat-sky Gaussian covariance matrix.
nmt_covar_workspace_flat_write_fits
void nmt_covar_workspace_flat_write_fits(nmt_covar_workspace_flat *cw, char *fname)
Saves nmt_covar_workspace_flat structure to file.
nmt_decouple_cl_l_flat
void nmt_decouple_cl_l_flat(nmt_workspace_flat *w, flouble **cl_in, flouble **cl_noise_in, flouble **cl_bias, flouble **cl_out)
Inverts mode-coupling matrix.
nmt_field_flat::pure_e
int pure_e
>0 if E-modes have been purified.
Definition: namaster.h:351
nmt_curvedsky_info::lmax_sht
int lmax_sht
Maximum multipole to compute spherical harmonic transform.
Definition: namaster.h:473
nmt_binning_scheme_flat::ell_0_list
flouble * ell_0_list
Lower edge of each bandpower.
Definition: namaster.h:73
nmt_flatsky_info::n_ell
int n_ell
Number of |k|-values for Fourier-space sampling.
Definition: namaster.h:318
nmt_binning_scheme_flat
Flat-sky bandpowers.
Definition: namaster.h:71
nmt_covar_workspace_flat::xi00_1122
flouble ** xi00_1122
First (a1b1-a2b2), 00, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1169
nmt_apodize_mask
void nmt_apodize_mask(long nside, flouble *mask_in, flouble *mask_out, flouble aposize, char *apotype)
Apodize full-sky mask.
nmt_k_function_alloc
nmt_k_function * nmt_k_function_alloc(int nk, flouble *karr, flouble *farr, flouble y0, flouble yf, int is_const)
nmt_k_function creator.
nmt_covar_workspace::xi22p_1122
flouble ** xi22p_1122
First (a1b1-a2b2), 22+, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1242
nmt_k_function::spl
gsl_spline * spl
GSL spline interpolator.
Definition: namaster.h:271
nmt_workspace::bin
nmt_binning_scheme * bin
Bandpowers defining the binning.
Definition: namaster.h:943
nmt_covar_workspace_flat
Flat-sky Gaussian covariance matrix.
Definition: namaster.h:1167
nmt_covar_workspace::xi00_1221
flouble ** xi00_1221
Second (a1b2-a2b1), 00, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1239
nmt_compute_deprojection_bias
void nmt_compute_deprojection_bias(nmt_field *fl1, nmt_field *fl2, flouble **cl_proposal, flouble **cl_bias, int niter)
Computes deprojection bias.
nmt_k_function::is_const
int is_const
If >0, this function is just a constant.
Definition: namaster.h:266
nmt_workspace
Full-sky mode-coupling matrix.
Definition: namaster.h:933
nmt_binning_scheme_flat::ell_f_list
flouble * ell_f_list
Upper edge of each bandpower.
Definition: namaster.h:74
nmt_unbin_cls_flat
void nmt_unbin_cls_flat(nmt_binning_scheme_flat *bin, flouble **cls_in, int nl, flouble *larr, flouble **cls_out, int ncls)
Returns binned power spectra interpolated into an given set of multipoles.
nmt_flatsky_info::dell
flouble dell
Width of the Fourier-space rings. This is found as min(2 π / lx,2 π / ly).
Definition: namaster.h:319
nmt_k_function_eval
flouble nmt_k_function_eval(nmt_k_function *f, flouble k, gsl_interp_accel *intacc)
nmt_k_function evaluator.
nmt_field_flat::ntemp
int ntemp
Number of contaminant templates.
Definition: namaster.h:359
nmt_field::lmax
int lmax
Maximum multipole used.
Definition: namaster.h:546
nmt_curvedsky_info::npix
long npix
Total number of pixels (given by nx * ny.
Definition: namaster.h:477
nmt_covar_workspace::xi22p_1221
flouble ** xi22p_1221
Second (a1b2-a2b1), 22+, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1243
nmt_ell_eff_flat
void nmt_ell_eff_flat(nmt_binning_scheme_flat *bin, flouble *larr)
Returns effective multipoles.
nmt_flatsky_info_alloc
nmt_flatsky_info * nmt_flatsky_info_alloc(int nx, int ny, flouble lx, flouble ly)
nmt_flatsky_info constructor
nmt_binning_scheme::f_ell
flouble ** f_ell
Multiplicative ell factor.
Definition: namaster.h:171
nmt_workspace_flat::coupling_matrix_binned
flouble ** coupling_matrix_binned
Binned MCM.
Definition: namaster.h:755
nmt_field_flat::temp
flouble *** temp
Contaminant template maps (mask-multiplied but NOT purified).
Definition: namaster.h:360
nmt_update_coupling_matrix
void nmt_update_coupling_matrix(nmt_workspace *w, int n_rows, double *new_matrix)
Updates the mode coupling matrix with a new one.Saves nmt_workspace structure to file.
nmt_workspace_flat::coupling_matrix_unbinned
flouble ** coupling_matrix_unbinned
Unbinned MCM.
Definition: namaster.h:754
nmt_flatsky_info::lx
flouble lx
Length of the x dimension (in steradians)
Definition: namaster.h:315
nmt_covar_workspace_flat::bin
nmt_binning_scheme_flat * bin
Bandpowers defining the binning.
Definition: namaster.h:1168
nmt_compute_coupling_matrix_flat
nmt_workspace_flat * nmt_compute_coupling_matrix_flat(nmt_field_flat *fl1, nmt_field_flat *fl2, nmt_binning_scheme_flat *bin, flouble lmn_x, flouble lmx_x, flouble lmn_y, flouble lmx_y, int is_teb)
Computes mode-coupling matrix.
nmt_curvedsky_info::is_healpix
int is_healpix
is this HEALPix pixelization?
Definition: namaster.h:471
nmt_k_function::x0
flouble x0
Lower edge of spline interpolation.
Definition: namaster.h:267
nmt_covar_workspace::xi22m_1122
flouble ** xi22m_1122
First (a1b1-a2b2), 22-, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1244
nmt_field_flat::nmaps
int nmaps
Number of maps in the field (2 for spin-2, 1 for spin-0).
Definition: namaster.h:356
nmt_workspace::coupling_matrix_unbinned
flouble ** coupling_matrix_unbinned
Unbinned mode-coupling matrix.
Definition: namaster.h:942
nmt_binning_scheme::ell_max
int ell_max
Maximum multipole included.
Definition: namaster.h:172
nmt_flatsky_info::nx
int nx
Number of grid points in the x dimension.
Definition: namaster.h:312
nmt_master_calculator_free
void nmt_master_calculator_free(nmt_master_calculator *c)
nmt_field::mask
flouble * mask
Field&#39;s mask (an array of npix values).
Definition: namaster.h:549
nmt_field::mask_only
int mask_only
this field only contains a mask, and beam. No alms, maps or anything else.
Definition: namaster.h:561
nmt_workspace_flat_write_fits
void nmt_workspace_flat_write_fits(nmt_workspace_flat *w, char *fname)
Saves nmt_workspace_flat structure to file.
nmt_binning_scheme::ell_list
int ** ell_list
List of multipoles in each bandpowers.
Definition: namaster.h:169
nmt_field_flat::maps
flouble ** maps
Observed field values. When initialized, these maps are already multiplied by the mask...
Definition: namaster.h:357
nmt_covar_workspace_write_fits
void nmt_covar_workspace_write_fits(nmt_covar_workspace *cw, char *fname)
Saves nmt_covar_workspace structure to file.
nmt_bin_cls_flat
void nmt_bin_cls_flat(nmt_binning_scheme_flat *bin, int nl, flouble *larr, flouble **cls_in, flouble **cls_out, int ncls)
Returns average of input power spectrum into bandpowers.
nmt_bins_flat_free
void nmt_bins_flat_free(nmt_binning_scheme_flat *bin)
nmt_binning_scheme_flat destructor
fcomplex
double complex fcomplex
Definition: namaster.h:33
nmt_field_flat_alloc
nmt_field_flat * nmt_field_flat_alloc(int nx, int ny, flouble lx, flouble ly, flouble *mask, int spin, flouble **maps, int ntemp, flouble ***temp, int nl_beam, flouble *l_beam, flouble *beam, int pure_e, int pure_b, double tol_pinv, int masked_input, int is_lite, int mask_only)
nmt_field_flat constructor
nmt_workspace_flat::coupling_matrix_perm
gsl_permutation * coupling_matrix_perm
Complements coupling_matrix_binned_gsl for inversion.
Definition: namaster.h:759
nmt_field_flat_free
void nmt_field_flat_free(nmt_field_flat *fl)
nmt_field_flat destructor
nmt_workspace_flat::n_cells
int * n_cells
Number of unmasked Fourier-space grid points contributing to a given bandpower.
Definition: namaster.h:753
nmt_workspace_flat
Flat-sky mode-coupling matrix.
Definition: namaster.h:743
nmt_field_flat::spin
int spin
field&#39;s spin (>=0).
Definition: namaster.h:355
nmt_diff_curvedsky_info
int nmt_diff_curvedsky_info(nmt_curvedsky_info *c1, nmt_curvedsky_info *c2)
Compare two nmt_curvedsky_info structs.
nmt_master_calculator::has_00
int has_00
Definition: namaster.h:954
nmt_workspace_flat::pe1
int pe1
Is the E-mode component of the first field purified?
Definition: namaster.h:747
nmt_covar_workspace_free
void nmt_covar_workspace_free(nmt_covar_workspace *cw)
nmt_covar_workspace destructor.
nmt_covar_workspace_flat::xi22p_1122
flouble ** xi22p_1122
First (a1b1-a2b2), 22p, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1173
nmt_covar_workspace::xi00_1122
flouble ** xi00_1122
First (a1b1-a2b2), 00, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1238
nmt_flatsky_info::ell_min
flouble * ell_min
Array of n_ell values containing the lower edges of each of the |k| rings.
Definition: namaster.h:321
nmt_curvedsky_info_alloc
nmt_curvedsky_info * nmt_curvedsky_info_alloc(int is_healpix, long nside, int lmax_sht, int nx0, int ny0, flouble Dtheta, flouble Dphi, flouble phi0, flouble theta0)
nmt_curvedsky_info creator
nmt_purify_flat
void nmt_purify_flat(nmt_field_flat *fl, flouble *mask, fcomplex **walm0, flouble **maps_in, flouble **maps_out, fcomplex **alms)
E- or B-mode purifies a given pair of flat-sky (Q,U) maps.
nmt_covar_workspace
Full-sky Gaussian covariance matrix.
Definition: namaster.h:1236
nmt_master_calculator::s2
int s2
Definition: namaster.h:953
nmt_binning_scheme
Full-sky bandpowers.
Definition: namaster.h:166
nmt_workspace_free
void nmt_workspace_free(nmt_workspace *w)
nmt_workspace destructor
nmt_field_read
nmt_field * nmt_field_read(int is_healpix, char *fname_mask, char *fname_maps, char *fname_temp, char *fname_beam, int spin, int pure_e, int pure_b, int n_iter_mask_purify, double tol_pinv, int niter)
nmt_field constructor from file.
nmt_field_flat::alms
fcomplex ** alms
Fourier-transfoms of the maps.
Definition: namaster.h:358
nmt_workspace_read_fits
nmt_workspace * nmt_workspace_read_fits(char *fname)
Builds nmt_workspace structure from file.
nmt_ell_eff
void nmt_ell_eff(nmt_binning_scheme *bin, flouble *larr)
Returns effective multipoles.
nmt_curvedsky_info::n_eq
long n_eq
equivalent of nside, number of pixels in the equatorial ring
Definition: namaster.h:472
nmt_compute_bandpower_windows
void nmt_compute_bandpower_windows(nmt_workspace *w, double *bpw_win_out)
Returns the bandpower window functions for this workspace.
nmt_workspace_flat::pb2
int pb2
Is the B-mode component of the second field purified?
Definition: namaster.h:750
nmt_workspace_flat::ncls
int ncls
Number of power spectra (1, 2 or 4 depending of the spins of the fields being correlated.
Definition: namaster.h:744
nmt_couple_cl_l
void nmt_couple_cl_l(nmt_workspace *w, flouble **cl_in, flouble **cl_out)
Mode-couples an input power spectrum.
nmt_compute_coupling_matrix
nmt_workspace * nmt_compute_coupling_matrix(nmt_field *fl1, nmt_field *fl2, nmt_binning_scheme *bin, int is_teb, int niter, int lmax_mask, int l_toeplitz, int l_exact, int dl_band)
Computes mode-coupling matrix.
nmt_flatsky_info::ny
int ny
Number of grid points in the y dimension.
Definition: namaster.h:313
nmt_compute_uncorr_noise_deprojection_bias
void nmt_compute_uncorr_noise_deprojection_bias(nmt_field *fl1, flouble *map_var, flouble **cl_bias, int niter)
Noise bias from uncorrelated noise map.
nmt_covar_workspace_flat_read_fits
nmt_covar_workspace_flat * nmt_covar_workspace_flat_read_fits(char *fname)
Builds nmt_covar_workspace_flat structure from file.
nmt_covar_workspace_flat::xi22m_1221
flouble ** xi22m_1221
Second (a1b2-a2b1), 22m, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1176
nmt_compute_deprojection_bias_flat
void nmt_compute_deprojection_bias_flat(nmt_field_flat *fl1, nmt_field_flat *fl2, nmt_binning_scheme_flat *bin, flouble lmn_x, flouble lmx_x, flouble lmn_y, flouble lmx_y, int nl_prop, flouble *l_prop, flouble **cl_proposal, flouble **cl_bias)
Computes deprojection bias.
nmt_field_flat::npix
long npix
Number of pixels in all maps (also contained in fs).
Definition: namaster.h:350
nmt_master_calculator::xi_0s
flouble **** xi_0s
Definition: namaster.h:957
nmt_workspace_update_beams
void nmt_workspace_update_beams(nmt_workspace *w, int nl1, double *b1, int nl2, double *b2)
Updates the beams associated to this workspace.
nmt_field::maps
flouble ** maps
Observed field values. When initialized, these maps are already multiplied by the mask...
Definition: namaster.h:553
nmt_master_calculator::xi_00
flouble *** xi_00
Definition: namaster.h:955
nmt_workspace::ncls
int ncls
Number of power spectra (1, 2 or 4 depending of the spins of the fields being correlated.
Definition: namaster.h:938
nmt_covar_workspace_flat::xi00_1221
flouble ** xi00_1221
Second (a1b2-a2b1), 00, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1170
nmt_covar_workspace_flat::xi02_1122
flouble ** xi02_1122
First (a1b1-a2b2), 02, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1171
nmt_apodize_mask_flat
void nmt_apodize_mask_flat(int nx, int ny, flouble lx, flouble ly, flouble *mask_in, flouble *mask_out, flouble aposize, char *apotype)
Apodize flat-sky mask.
nmt_master_calculator::xi_pp
flouble **** xi_pp
Definition: namaster.h:959
nmt_synfast_sph
flouble ** nmt_synfast_sph(nmt_curvedsky_info *cs, int nfields, int *spin_arr, int lmax, flouble **cells, flouble **beam_fields, int seed)
Gaussian realizations of full-sky fields.
nmt_curvedsky_info::nx_short
int nx_short
Number of grid points in the x dimension before completing the circle.
Definition: namaster.h:474
nmt_field_flat::mask_only
int mask_only
this field only contains a mask, and beam. No alms, maps or anything else.
Definition: namaster.h:365
nmt_couple_cl_l_flat_fast
void nmt_couple_cl_l_flat_fast(nmt_workspace_flat *w, int nl, flouble *larr, flouble **cl_in, flouble **cl_out)
Mode-couples an input power spectrum.
flouble
double flouble
Definition: namaster.h:32
nmt_curvedsky_info::theta0
flouble theta0
Definition: namaster.h:481
nmt_workspace::lmax_mask
int lmax_mask
Mask resolution.
Definition: namaster.h:936
nmt_bins_create
nmt_binning_scheme * nmt_bins_create(int nell, int *bpws, int *ells, flouble *weights, flouble *f_ell, int lmax)
nmt_binning_scheme generic constructor.
nmt_bin_cls
void nmt_bin_cls(nmt_binning_scheme *bin, flouble **cls_in, flouble **cls_out, int ncls)
Returns average of input power spectrum into bandpowers.
nmt_covar_workspace::xi22m_1221
flouble ** xi22m_1221
Second (a1b2-a2b1), 22-, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1245
nmt_flatsky_info_free
void nmt_flatsky_info_free(nmt_flatsky_info *fs)
nmt_flatsky_info destructor.
nmt_binning_scheme::w_list
flouble ** w_list
List of weights associated to each multipole in ell_list.
Definition: namaster.h:170
nmt_field_flat::a_mask
fcomplex ** a_mask
Fourier transform of the mask. Only computed if E or B are purified.
Definition: namaster.h:354
nmt_k_function::yf
flouble yf
Function will take this value for x > xf.
Definition: namaster.h:270
nmt_field::nmaps
int nmaps
Number of maps in the field (2 for spin-2, 1 for spin-0).
Definition: namaster.h:552
nmt_field_flat::lite
int lite
lightweight field (no maps, temp, a_temp or a_mask)
Definition: namaster.h:364
nmt_master_calculator::pure_any
int pure_any
Definition: namaster.h:965
nmt_flatsky_info
Flat-sky information.
Definition: namaster.h:311
nmt_workspace::pcl_masks
flouble * pcl_masks
Pseudo-CL of the masks.
Definition: namaster.h:941
nmt_k_function_free
void nmt_k_function_free(nmt_k_function *f)
nmt_k_function destructor
nmt_covar_workspace_flat::xi22m_1122
flouble ** xi22m_1122
First (a1b1-a2b2), 22m, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1175
nmt_field::beam
flouble * beam
Field&#39;s beam (defined on all multipoles up to lmax).
Definition: namaster.h:559
nmt_field::a_mask
fcomplex ** a_mask
Spherical transform of the mask. Only computed if E or B are purified.
Definition: namaster.h:550
nmt_compute_coupled_cell_flat
void nmt_compute_coupled_cell_flat(nmt_field_flat *fl1, nmt_field_flat *fl2, nmt_binning_scheme_flat *bin, flouble **cl_out, flouble lmn_x, flouble lmx_x, flouble lmn_y, flouble lmx_y)
Coupled pseudo-CL.
nmt_curvedsky_info::Delta_phi
flouble Delta_phi
pixel size in phi direction
Definition: namaster.h:479
nmt_flatsky_info::i_dell
flouble i_dell
1 / dell
Definition: namaster.h:320
nmt_bins_constant
nmt_binning_scheme * nmt_bins_constant(int nlb, int lmax, int is_l2)
nmt_binning_scheme constructor for constant bandpowers.
nmt_covar_workspace_flat_init
nmt_covar_workspace_flat * nmt_covar_workspace_flat_init(nmt_field_flat *fla1, nmt_field_flat *fla2, nmt_binning_scheme_flat *ba, nmt_field_flat *flb1, nmt_field_flat *flb2, nmt_binning_scheme_flat *bb)
nmt_covar_workspace_flat constructor
nmt_compute_master_coefficients
nmt_master_calculator * nmt_compute_master_coefficients(int lmax, int lmax_mask, int npcl, flouble **pcl_masks, int s1, int s2, int pure_e1, int pure_b1, int pure_e2, int pure_b2, int do_teb, int l_toeplitz, int l_exact, int dl_band)
nmt_master_calculator::has_0s
int has_0s
Definition: namaster.h:956
nmt_workspace::coupling_matrix_perm
gsl_permutation * coupling_matrix_perm
Complements coupling_matrix_binned_gsl for inversion.
Definition: namaster.h:945
nmt_master_calculator::npcl
int npcl
Definition: namaster.h:951
nmt_field::spin
int spin
field&#39;s spin (>=0).
Definition: namaster.h:551
nmt_covar_workspace_flat::xi22p_1221
flouble ** xi22p_1221
Second (a1b2-a2b1), 22p, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1174
nmt_k_function::xf
flouble xf
Upper edge of spline interpolation.
Definition: namaster.h:268
nmt_field::lite
int lite
lightweight field (no maps, temp, a_temp or a_mask)
Definition: namaster.h:560
nmt_field::matrix_M
gsl_matrix * matrix_M
Inverse contaminant covariance matrix (see scientific documentation or companion paper).
Definition: namaster.h:558
nmt_field_flat::fs
nmt_flatsky_info * fs
Structure defining patch geometry.
Definition: namaster.h:349
nmt_field::cs
nmt_curvedsky_info * cs
pixelization parameters
Definition: namaster.h:544
nmt_flatsky_info::ly
flouble ly
Length of the y dimension (in steradians)
Definition: namaster.h:316
nmt_decouple_cl_l
void nmt_decouple_cl_l(nmt_workspace *w, flouble **cl_in, flouble **cl_noise_in, flouble **cl_bias, flouble **cl_out)
Inverts mode-coupling matrix.
nmt_field_flat::mask
flouble * mask
Field&#39;s mask (an array of npix values).
Definition: namaster.h:353
nmt_workspace::is_teb
int is_teb
Does it hold all MCM elements to compute all of spin0-spin0, 0-2 and 2-2 correlations?
Definition: namaster.h:937
nmt_master_calculator::pure_e1
int pure_e1
Definition: namaster.h:961
nmt_workspace::coupling_matrix_binned
gsl_matrix * coupling_matrix_binned
GSL version of MCM (prepared for inversion)
Definition: namaster.h:944
nmt_field_flat::matrix_M
gsl_matrix * matrix_M
Inverse contaminant covariance matrix (see scientific documentation or companion paper).
Definition: namaster.h:362
nmt_master_calculator::has_ss
int has_ss
Definition: namaster.h:958
nmt_master_calculator::npure_ss
int npure_ss
Definition: namaster.h:967
nmt_synfast_flat
flouble ** nmt_synfast_flat(int nx, int ny, flouble lx, flouble ly, int nfields, int *spin_arr, int nl_beam, flouble *l_beam, flouble **beam_fields, int nl_cell, flouble *l_cell, flouble **cell_fields, int seed)
Gaussian realizations of flat-sky fields.
nmt_workspace_flat::is_teb
int is_teb
Does it hold all MCM elements to compute all of spin0-spin0, 0-2 and 2-2 correlations?
Definition: namaster.h:752
nmt_covar_workspace_flat_free
void nmt_covar_workspace_flat_free(nmt_covar_workspace_flat *cw)
nmt_covar_workspace_flat destructor.
nmt_compute_gaussian_covariance_coupled
void nmt_compute_gaussian_covariance_coupled(nmt_covar_workspace *cw, int spin_a, int spin_b, int spin_c, int spin_d, nmt_workspace *wa, nmt_workspace *wb, flouble **clac, flouble **clad, flouble **clbc, flouble **clbd, flouble *covar_out)
Compute full-sky Gaussian covariance matrix.
nmt_bins_read
nmt_binning_scheme * nmt_bins_read(char *fname, int lmax)
nmt_binning_scheme constructor from file
nmt_compute_coupled_cell
void nmt_compute_coupled_cell(nmt_field *fl1, nmt_field *fl2, flouble **cl_out)
Coupled pseudo-CL.
nmt_binning_scheme::n_bands
int n_bands
Number of bandpowers.
Definition: namaster.h:167
nmt_workspace_flat::bin
nmt_binning_scheme_flat * bin
Bandpowers defining the binning.
Definition: namaster.h:756
nmt_binning_scheme::nell_list
int * nell_list
Number of multipoles belonging to each bandpower.
Definition: namaster.h:168
nmt_covar_workspace::lmax
int lmax
Maximum multipole for the first set of power spectra.
Definition: namaster.h:1237
nmt_k_function::y0
flouble y0
Function will take this value for x < x0.
Definition: namaster.h:269
nmt_master_calculator::s1
int s1
Definition: namaster.h:952
nmt_bins_free
void nmt_bins_free(nmt_binning_scheme *bin)
nmt_binning_scheme destructor
nmt_workspace_write_fits
void nmt_workspace_write_fits(nmt_workspace *w, char *fname)
Saves nmt_workspace structure to file.
nmt_covar_workspace_init
nmt_covar_workspace * nmt_covar_workspace_init(nmt_field *fla1, nmt_field *fla2, nmt_field *flb1, nmt_field *flb2, int lmax, int niter, int l_toeplitz, int l_exact, int dl_band)
nmt_covar_workspace constructor
nmt_compute_power_spectra_flat
nmt_workspace_flat * nmt_compute_power_spectra_flat(nmt_field_flat *fl1, nmt_field_flat *fl2, nmt_binning_scheme_flat *bin, flouble lmn_x, flouble lmx_x, flouble lmn_y, flouble lmx_y, nmt_workspace_flat *w0, flouble **cl_noise, int nl_prop, flouble *l_prop, flouble **cl_prop, flouble **cl_out)
Computes pseudo-CL specrum.
nmt_covar_workspace_flat::xi02_1221
flouble ** xi02_1221
Second (a1b2-a2b1), 02, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1172
nmt_field_flat::pure_b
int pure_b
>0 if B-modes have been purified.
Definition: namaster.h:352
nmt_curvedsky_info::phi0
flouble phi0
Definition: namaster.h:480
nmt_curvedsky_info::nx
int nx
Number of grid points in the phi dimension.
Definition: namaster.h:475
nmt_curvedsky_info_copy
nmt_curvedsky_info * nmt_curvedsky_info_copy(nmt_curvedsky_info *cs_in)
Makes a copy of a nmt_curvedsky_info structure.
nmt_field::pure_b
int pure_b
>0 if B-modes have been purified
Definition: namaster.h:548
nmt_master_calculator::pure_b1
int pure_b1
Definition: namaster.h:963
nmt_master_calculator::xi_mm
flouble **** xi_mm
Definition: namaster.h:960
nmt_master_calculator::lmax
int lmax
Definition: namaster.h:949
nmt_workspace::cs
nmt_curvedsky_info * cs
curved sky geometry information.
Definition: namaster.h:939
nmt_unbin_cls
void nmt_unbin_cls(nmt_binning_scheme *bin, flouble **cls_in, flouble **cls_out, int ncls)
Returns binned power spectra interpolated into output multipoles.
nmt_extend_CAR_map
flouble * nmt_extend_CAR_map(nmt_curvedsky_info *cs, flouble *map_in)
Extend CAR map to cover the full circle.
nmt_flatsky_info::npix
long npix
Total number of pixels (given by nx * ny.
Definition: namaster.h:314
nmt_flatsky_info::pixsize
flouble pixsize
Pixel area (given by lx * ly / ( nx * ny))
Definition: namaster.h:317
nmt_workspace_flat::fs
nmt_flatsky_info * fs
Contains information about rectangular flat-sky patch.
Definition: namaster.h:751
nmt_compute_power_spectra
nmt_workspace * nmt_compute_power_spectra(nmt_field *fl1, nmt_field *fl2, nmt_binning_scheme *bin, nmt_workspace *w0, flouble **cl_noise, flouble **cl_proposal, flouble **cl_out, int niter, int lmax_mask, int l_toeplitz, int l_exact, int dl_band)
Computes pseudo-CL specrum.
nmt_master_calculator::pure_e2
int pure_e2
Definition: namaster.h:962
nmt_binning_scheme_flat::n_bands
int n_bands
Number of bandpowers stored.
Definition: namaster.h:72
nmt_covar_workspace::xi02_1122
flouble ** xi02_1122
First (a1b1-a2b2), 02, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1240
nmt_workspace::lmax_fields
int lmax_fields
Resolution of fields being correlated.
Definition: namaster.h:935
nmt_workspace_flat::lmax
flouble lmax
Maximum k-mode used.
Definition: namaster.h:757
nmt_field_flat::beam
nmt_k_function * beam
Function defining a circularly-symmetric beam function. Power spectra will be beam-deconvolved.
Definition: namaster.h:363
nmt_compute_gaussian_covariance
void nmt_compute_gaussian_covariance(nmt_covar_workspace *cw, int spin_a, int spin_b, int spin_c, int spin_d, nmt_workspace *wa, nmt_workspace *wb, flouble **clac, flouble **clad, flouble **clbc, flouble **clbd, flouble *covar_out)
Compute full-sky Gaussian covariance matrix.
nmt_field::ntemp
int ntemp
Number of contaminant templates.
Definition: namaster.h:555
nmt_covar_workspace::xi02_1221
flouble ** xi02_1221
Second (a1b2-a2b1), 02, mode coupling matrix (see scientific documentation)
Definition: namaster.h:1241
nmt_workspace_flat::pb1
int pb1
Is the B-mode component of the first field purified?
Definition: namaster.h:749
nmt_field::npix
long npix
Number of pixels in all maps.
Definition: namaster.h:545
nmt_curvedsky_info
Curved-sky information.
Definition: namaster.h:470
nmt_workspace_flat::coupling_matrix_binned_gsl
gsl_matrix * coupling_matrix_binned_gsl
GSL version of MCM (prepared for inversion)
Definition: namaster.h:758
nmt_field
Full-sky field.
Definition: namaster.h:543
nmt_master_calculator::npure_0s
int npure_0s
Definition: namaster.h:966
nmt_field_flat
Flat-sky field.
Definition: namaster.h:348
nmt_field::temp
flouble *** temp
Contaminant template maps (mask-multiplied but NOT purified).
Definition: namaster.h:556
nmt_curvedsky_info::Delta_theta
flouble Delta_theta
pixel size in theta direction
Definition: namaster.h:478
nmt_workspace::beam_prod
flouble * beam_prod
Product of field beams.
Definition: namaster.h:940
nmt_workspace::lmax
int lmax
Maximum multipole used.
Definition: namaster.h:934
nmt_field_alloc_sph
nmt_field * nmt_field_alloc_sph(nmt_curvedsky_info *cs, flouble *mask, int spin, flouble **maps, int ntemp, flouble ***temp, flouble *beam, int pure_e, int pure_b, int n_iter_mask_purify, double tol_pinv, int niter, int masked_input, int is_lite, int mask_only)
nmt_field constructor
nmt_bins_flat_search_fast
int nmt_bins_flat_search_fast(nmt_binning_scheme_flat *bin, flouble l, int il)
Fast bin-searching routine for flat-sky bandpowers.
nmt_field::alms
fcomplex ** alms
Spherical harmonic transfoms of the maps.
Definition: namaster.h:554